flush method
void
flush()
Persists the cassette to store if there are unsaved recordings. No-op when there is no store or nothing changed.
Implementation
void flush() {
if (store != null && _dirty) {
store!.save(cassette);
_dirty = false;
}
}